@@ -246,7 +246,7 @@ def HRC(X, low_bound=0., up_bound=1.0, nb_clusters = 10):
     low_bound = min(low_bound, 1 / X.shape[1])
 
     # Compute covariance and correlation matrix
-    correl_mat = X.corr().fillna(0).values
+    correl_mat = X.corr().fillna(0).valuesfro
 
     dist = 1 - correl_mat
     dim = len(dist)
@@ -294,14 +294,11 @@ def _compute_hrc_allocation(covar, clusters, dim, Z):
             weights, np.dot(covar[cluster, :][:, cluster], weights))
 
     for merge in range(nb_clusters - 1):
-        print('id merge:', merge)
         left = int(Z[dim - 2 - merge, 0])
         right = int(Z[dim - 2 - merge, 1])
         left_cluster = _seriation(Z, dim, left)
         right_cluster = _seriation(Z, dim, right)
 
-        print(len(left_cluster),
-              len(right_cluster))
         ids_left_cluster = []
         ids_right_cluster = []
         for id_cluster, cluster in clusters.items():
