@@ -21,7 +21,7 @@ def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard
         y_pred = forecasting_model.predict(X_test, method)
         forecasting_series.loc[slice_s] = y_pred
 
-        confusion_matrix = confusion_matrix(y_test > 0, y_pred > 0)
+        matrix = confusion_matrix(y_test > 0, y_pred > 0)
         rmse = mean_squared_error(y_test, y_pred)
         accuracy = accuracy_score(y_test > 0, y_pred > 0)
 
@@ -30,7 +30,7 @@ def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard
             print('accuracy')
             print(accuracy)
             print('confusion matrix')
-            print(confusion_matrix)
+            print(matrix)
 
     return forecasting_series
 
